//
//	VERSION MPLAB IDE V.8.63 Y COMPILADOR C18 LITE V3.40
//
//	Moises Melendez 	sesowm@hotmail.com
//
//	Codigo fuente para el sensor de llenado de agua, si el sensor detecta que el contenedor no esta
//	lleno activa el relevador que controla una bomba de llenado, si se detecta que el contenedor 
//	esta lleno se desactiva el relevador
//	
//	Se utilza el Sensor de nivel de agua en acero inoxidable, modelo RG-1045S. Contactos de 0.5A @ 100 VCD
//
//	El sistema bolt muestra en el LCD los mensajes:
//
//			"    No lleno	 "
//			"Contenedor lleno"
//
//	Al indicar el estado del contenedor de agua.
//
//	Conexiones del sensor y el sistema Bolt
//
//										
//
//									  CONECTOR J6
//
//										-|RA4
//				    SENSOR				-|RA5
//										-|RC0	
//				  	  |------------------|RC1
//		  			  |					-|+5V		SISTEMA BOLT-PIC18F2550
//		  			  ||-----------------|GND
//					 _||_
//					|	 |			
//					|____|			
//
//	El sensor no tiene polaridad por lo que pueden intercambiarse sus conexiones.
//
//	Importante el switch 4 debe estar en la poisicin OFF para el correcto funcionamiento del sistema
//			

#include <p18cxxx.h>
#include <delays.h>
#include <string.h>
#include <stdio.h>		//librera sprintf()
#include <stdlib.h>		//libreras atoi(),atof()
#include "18F2550BOLT.h"

#define TRUE	    1
#define ACTIVADO    1
#define DESACTIVADO 0

extern void _startup( void ); // See c018i.c in your C18 compiler dir 
#pragma code _RESET_INTERRUPT_VECTOR = 0x000800 
void _reset( void ) 
{ 
    _asm goto _startup _endasm 
} 

#pragma code

void writeLCDmsg(const far rom char * message);
 
void main()
{
	unsigned char estado_actual=0, estado_anterior=1;
	init_bolt();
	InitLCD();
	TRISCbits.RC1=1;
	RELE=DESACTIVADO;
	writeLCDmsg((const far rom char*)"Sensor de nivel ");
	delay_ms(1000);
	
	while(TRUE)
	{
		if(estado_actual!=estado_anterior)  
		{
			estado_anterior=estado_actual;
			if(!PORTCbits.RC1) 	
			{
				writeLCDmsg((const far rom char*)"  Relevador ON  ");
				RELE=ACTIVADO;
			}	
			else 
			{				
				writeLCDmsg((const far rom char*)"Contenedor lleno");
				RELE=DESACTIVADO;
			}
		}
		estado_actual=PORTCbits.RC1;
	}
} 

//
//	Funcin que enva una cadena de caracteres en ROM al LCD
//	Recibe la referencia de la cadena y enva cada uno de los caracteres
//	que componen la cadena en ROM, no retorna valor.
//
void writeLCDmsg(const far rom char * message)
{
	unsigned char i;
	ClearScreen();							// Limpia las pantalla
	GotoXY(0,0);							
	for(i=0; i<8; i++) PutLCD(message[i]);	// Escribe los caracteres al LCD
	GotoXY(1,0);
	for(i=8; i<strlenpgm(message);i++) PutLCD(message[i]);
} 



